fluidfft.bench
==============

.. automodule:: fluidfft.bench

   
   
   .. rubric:: Functions

   .. autosummary::
   
      bench_all
      bench_like_cpp_as_arg
      bench_like_cpp_return
      compare_benchs
      parse_args_dim
      pourc
      run
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      MyValueError
   
   